@@ -123,8 +123,8 @@ sub readConfig {
 					die "invalid line in section network: $line\n";
 				}
 			} elsif ($state eq 'INTERFACE') {
-				if ($line =~ /^\s*([a-zA-Z0-9_-]+)\s+(.*)$/) {
-					$$Interfaces{$1}.="$2 ";
+				if ($line =~ /^\s*([a-zA-Z0-9_-]+(:\d+)?)\s+(.*)$/) {
+					$$Interfaces{$1}.="$3 ";
 				} else {
 					die "invalid line in section interface: $line\n";
 				}
@@ -409,7 +409,7 @@ sub validateData {
 		$$Interfaces{$key} = resolveHashentries($$Interfaces{$key}, $Interfaces);
 	}
 	foreach $key (keys (%$Interfaces)) {
-		if (!($$Interfaces{$key} =~ /^[a-zA-Z0-9+ ]+$/)) {
+		if (!($$Interfaces{$key} =~ /^[a-zA-Z0-9+ ]+(:\d+)?$/)) {
 			die "invalid character in interface definition: $$Interfaces{$key}\n";
 		}
 	}
@@ -837,11 +837,18 @@ sub validateData {
 					}
 					if ($2) {
 						my $param=$2;
-						if ($param =~ /^([^,]+)(,\d+|)$/) {
+						if ($param =~ /^([^:]+)(:\d+|)$/) {
 							if (checkLimit $1) {
 								$$rule{'Limit'}=$1;
 								if ($2) {
-									$$rule{'Limit-burst'}=$2;
+									# no need to check burst since it 
+									# is guaranteed to be either empty
+									# or digits only (plus leading colon).
+									# Empty results in other part of if
+									# clause.
+									my $burst=$2;
+									$burst=~s/^://;
+									$$rule{'Limit-burst'}=$burst;
 								} else {
 									$$rule{'Limit-burst'}=$$Sysconfig{'Burst'};
 								}
